==> GeoNetwork-4.0.7-SNAPSHOT-2025-10-22.zip: web/geonetwork/catalog/components/common/openlayers/olDecorateInteraction.js <==
/*
 * Copyright (C) 2001-2016 Food and Agriculture Organization of the
 * United Nations (FAO-UN), United Nations World Food Programme (WFP)
 * and United Nations Environment Programme (UNEP)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * Contact: Jeroen Ticheler - FAO - Viale delle Terme di Caracalla 2,
 * Rome - Italy. email: geonetwork@osgeo.org
 */

(function () {

  goog.provide('gn_olDecorateInteraction')

  var module = angular.module('gn_olDecorateInteraction', [])

  /**
   * Provides a function that adds an "active" property (using
   * `Object.defineProperty`) to an interaction, making it possible to use ngModel
   * to activate/deactivate interactions.
   *
   * Example:
   *
   *      <input type="checkbox" ngModel="interaction.active" />
   *
   * See our live example: {@link ../examples/interactiontoggle.html}
   *
   * @typedef {function(ol.interaction.Interaction)}
   * @ngdoc service
   * @ngname olDecorateInteraction
   */

  /**
   * @param {ol.interaction.Interaction} interaction Interaction to decorate.
   */
  var decorateInteraction = function(interaction) {

    Object.defineProperty(interaction, 'active', {
      get: function() {
        return interaction.getActive();
      },
      set: function(val) {
        interaction.setActive(val);
      }
    });
  };

  module.value('olDecorateInteraction', decorateInteraction)
})()

==> GeoNetwork-4.2.15-SNAPSHOT-2025-12-04.zip: web/geonetwork/catalog/components/common/openlayers/olDecorateInteraction.js <==
/*
 * Copyright (C) 2001-2016 Food and Agriculture Organization of the
 * United Nations (FAO-UN), United Nations World Food Programme (WFP)
 * and United Nations Environment Programme (UNEP)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * Contact: Jeroen Ticheler - FAO - Viale delle Terme di Caracalla 2,
 * Rome - Italy. email: geonetwork@osgeo.org
 */

(function () {
  goog.provide("gn_olDecorateInteraction");

  var module = angular.module("gn_olDecorateInteraction", []);

  /**
   * Provides a function that adds an "active" property (using
   * `Object.defineProperty`) to an interaction, making it possible to use ngModel
   * to activate/deactivate interactions.
   *
   * Example:
   *
   *      <input type="checkbox" ngModel="interaction.active" />
   *
   * See our live example: {@link ../examples/interactiontoggle.html}
   *
   * @typedef {function(ol.interaction.Interaction)}
   * @ngdoc service
   * @ngname olDecorateInteraction
   */

  /**
   * @param {ol.interaction.Interaction} interaction Interaction to decorate.
   */
  var decorateInteraction = function (interaction) {
    Object.defineProperty(interaction, "active", {
      get: function () {
        return interaction.getActive();
      },
      set: function (val) {
        interaction.setActive(val);
      }
    });
  };

  module.value("olDecorateInteraction", decorateInteraction);
})();
